*****************
Development plans
*****************

pyspotify 2.x is a new Python wrapper for `libspotify
<https://developer.spotify.com/technologies/libspotify/>`__. This library is
still under active development.


v2.0.0: Final release
=====================

- Fix all remaining TODOs in code and tests.

- Fix all remaining FIXMEs in code and tests.

- Revisit all XXXs in code and tests.


Future plans
============

- Enforce that the same cache and settings directories are not used by multiple
  processes by maintaining a lock file.

- Iterate a few times over the docs to improve them as much as possible.

- Look into how asyncio support could work.
